<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv_SE">
<context>
    <name>RecentFiles</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Recent files history size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../RecentFiles.js" line="+35"/>
        <source>Recent Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../RecentFilesInit.js" line="+51"/>
        <source>&amp;Clear List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Open &amp;Recent</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
